Module section_header

Module section_header 

Modules

section_header32

Structs

SectionHeader
Section Headers are typically used by humans and static linkers for additional information or how to relocate the object

Constants

SHF_ALLOC
Occupies memory during execution.
SHF_COMPRESSED
Section with compressed data.
SHF_EXCLUDE
Section is excluded unless referenced or allocated (Solaris).
SHF_EXECINSTR
Executable.
SHF_FLAGS
SHF_GROUP
Section is member of a group.
SHF_INFO_LINK
`sh_info’ contains SHT index.
SHF_LINK_ORDER
Preserve order after combining.
SHF_MASKOS
OS-specific..
SHF_MASKPROC
Processor-specific.
SHF_MERGE
Might be merged.
SHF_NUM_REGULAR_FLAGS
Number of “regular” section header flags
SHF_ORDERED
Special ordering requirement (Solaris).
SHF_OS_NONCONFORMING
Non-standard OS specific handling required.
SHF_STRINGS
Contains nul-terminated strings.
SHF_TLS
Section hold thread-local data.
SHF_WRITE
Writable.
SHN_ABS
Associated symbol is absolute.
SHN_AFTER
Order section after all others (Solaris).
SHN_BEFORE
Order section before all others (Solaris).
SHN_COMMON
Associated symbol is common.
SHN_HIOS
End of OS-specific.
SHN_HIPROC
End of processor-specific.
SHN_HIRESERVE
End of reserved indices.
SHN_LOOS
Start of OS-specific.
SHN_LOPROC
Start of processor-specific.
SHN_LORESERVE
Start of reserved indices.
SHN_UNDEF
Undefined section.
SHN_XINDEX
Index is in extra table.
SHT_CHECKSUM
Checksum for DSO content.
SHT_DYNAMIC
Dynamic linking information.
SHT_DYNSYM
Dynamic linker symbol table.
SHT_FINI_ARRAY
Array of destructors.
SHT_GNU_ATTRIBUTES
Object attributes.
SHT_GNU_HASH
GNU-style hash table.
SHT_GNU_LIBLIST
Prelink library list.
SHT_GNU_VERDEF
Version definition section.
SHT_GNU_VERNEED
Version needs section.
SHT_GNU_VERSYM
Version symbol table.
SHT_GROUP
Section group.
SHT_HASH
Symbol hash table.
SHT_HIOS
End OS-specific type.
SHT_HIPROC
End of processor-specific.
SHT_HISUNW
Sun-specific high bound.
SHT_HIUSER
End of application-specific.
SHT_INIT_ARRAY
Array of constructors.
SHT_LOOS
Start OS-specific.
SHT_LOPROC
Start of processor-specific.
SHT_LOSUNW
Sun-specific low bound.
SHT_LOUSER
Start of application-specific.
SHT_NOBITS
Program space with no data (bss).
SHT_NOTE
Notes.
SHT_NULL
Section header table entry unused.
SHT_NUM
Number of defined types.
SHT_PREINIT_ARRAY
Array of pre-constructors.
SHT_PROGBITS
Program data.
SHT_REL
Relocation entries, no addends.
SHT_RELA
Relocation entries with addends.
SHT_SHLIB
Reserved.
SHT_STRTAB
String table.
SHT_SUNW_COMDAT
SHT_SUNW_MOVE
SHT_SUNW_SYMINFO
SHT_SYMTAB
Symbol table.
SHT_SYMTAB_SHNDX
Extended section indeces.
SHT_X86_64_UNWIND
X86-64 unwind information.
SIZEOF_SHDR

Functions

shf_to_str
sht_to_str