SectionHeader

Struct SectionHeader 

#[repr(C)]
pub struct SectionHeader { pub sh_name: u32, pub sh_type: u32, pub sh_flags: u64, pub sh_addr: u64, pub sh_offset: u64, pub sh_size: u64, pub sh_link: u32, pub sh_info: u32, pub sh_addralign: u64, pub sh_entsize: u64, }
Section Headers are typically used by humans and static linkers for additional information or how to relocate the object

NOTE section headers are strippable from a binary without any loss of portability/executability; do not rely on them being there!

Fields

sh_name: u32

Section name (string tbl index)

sh_type: u32

Section type

sh_flags: u64

Section flags

sh_addr: u64

Section virtual addr at execution

sh_offset: u64

Section file offset

sh_size: u64

Section size in bytes

sh_link: u32

Link to another section

sh_info: u32

Additional section information

sh_addralign: u64

Section alignment

sh_entsize: u64

Entry size if section holds table

Implementations

Source

impl SectionHeader

pub fn from_bytes(bytes: &[u8], shnum: usize) -> Vec<SectionHeader>

pub fn from_fd( fd: &mut File, offset: u64, shnum: usize, ) -> Result<Vec<SectionHeader>, Error>