ChunkMessage

Struct ChunkMessage 

pub struct ChunkMessage<R: Read + StreamLen> { /* private fields */ }
All data sent in chunks must be wrapped in a ChunkMessage.

It adds a one-byte header indicating the type of message being sent.

Implementations

Source

impl<R: Read + StreamLen> ChunkMessage<R>

pub fn new(message_type: ChunkMessageType, data: R) -> Self