pub struct DiskBacked<T: Eq + Serialize + Deserialize<'static>> { /* private fields */ }Expand description
A serializable struct that is backed by a JSON file on disk.
The disk version will be loaded on object creation. If it does not exist, or is invalid, the default value will be returned.
Implementations
Sourceimpl<T: Default + Eq + Serialize + DeserializeOwned> DiskBacked<T>
impl<T: Default + Eq + Serialize + DeserializeOwned> DiskBacked<T>
Sourceimpl<T: Eq + Serialize + DeserializeOwned> DiskBacked<T>
impl<T: Eq + Serialize + DeserializeOwned> DiskBacked<T>
pub fn from_path_with_default(path: &Path, default: T) -> Self
Sourcepub fn set(&mut self, new_value: T) -> Result<UpdateStatus>
pub fn set(&mut self, new_value: T) -> Result<UpdateStatus>
Updates self and writes the provided value to disk.