pub enum Clock {
Monotonic,
Boottime,
}Expand description
Calls clock_gettime Most interesting to us are: CLOCK_MONOTONIC: “clock that increments monotonically, tracking the time since an arbitrary point, and will continue to increment while the system is asleep.” CLOCK_BOOTTIME A nonsettable system-wide clock that is identical to CLOCK_MONOTONIC, except that it also includes any time that the system is suspended. This allows applications to get a suspend-aware monotonic clock without having to deal with the complications of CLOCK_REALTIME, which may have discontinuities if the time is changed using settimeofday(2) or similar.
Variants