Modules
Structs
- Section
Header - Section Headers are typically used by humans and static linkers for additional information or how to relocate the object
Constants
- SHF_
ALLOC - Occupies memory during execution.
- SHF_
COMPRESSED - Section with compressed data.
- SHF_
EXCLUDE - Section is excluded unless referenced or allocated (Solaris).
- SHF_
EXECINSTR - Executable.
- SHF_
FLAGS - SHF_
GROUP - Section is member of a group.
- SHF_
INFO_ LINK - `sh_info’ contains SHT index.
- SHF_
LINK_ ORDER - Preserve order after combining.
- SHF_
MASKOS - OS-specific..
- SHF_
MASKPROC - Processor-specific.
- SHF_
MERGE - Might be merged.
- SHF_
NUM_ REGULAR_ FLAGS - Number of “regular” section header flags
- SHF_
ORDERED - Special ordering requirement (Solaris).
- SHF_
OS_ NONCONFORMING - Non-standard OS specific handling required.
- SHF_
STRINGS - Contains nul-terminated strings.
- SHF_TLS
- Section hold thread-local data.
- SHF_
WRITE - Writable.
- SHN_ABS
- Associated symbol is absolute.
- SHN_
AFTER - Order section after all others (Solaris).
- SHN_
BEFORE - Order section before all others (Solaris).
- SHN_
COMMON - Associated symbol is common.
- SHN_
HIOS - End of OS-specific.
- SHN_
HIPROC - End of processor-specific.
- SHN_
HIRESERVE - End of reserved indices.
- SHN_
LOOS - Start of OS-specific.
- SHN_
LOPROC - Start of processor-specific.
- SHN_
LORESERVE - Start of reserved indices.
- SHN_
UNDEF - Undefined section.
- SHN_
XINDEX - Index is in extra table.
- SHT_
CHECKSUM - Checksum for DSO content.
- SHT_
DYNAMIC - Dynamic linking information.
- SHT_
DYNSYM - Dynamic linker symbol table.
- SHT_
FINI_ ARRAY - Array of destructors.
- SHT_
GNU_ ATTRIBUTES - Object attributes.
- SHT_
GNU_ HASH - GNU-style hash table.
- SHT_
GNU_ LIBLIST - Prelink library list.
- SHT_
GNU_ VERDEF - Version definition section.
- SHT_
GNU_ VERNEED - Version needs section.
- SHT_
GNU_ VERSYM - Version symbol table.
- SHT_
GROUP - Section group.
- SHT_
HASH - Symbol hash table.
- SHT_
HIOS - End OS-specific type.
- SHT_
HIPROC - End of processor-specific.
- SHT_
HISUNW - Sun-specific high bound.
- SHT_
HIUSER - End of application-specific.
- SHT_
INIT_ ARRAY - Array of constructors.
- SHT_
LOOS - Start OS-specific.
- SHT_
LOPROC - Start of processor-specific.
- SHT_
LOSUNW - Sun-specific low bound.
- SHT_
LOUSER - Start of application-specific.
- SHT_
NOBITS - Program space with no data (bss).
- SHT_
NOTE - Notes.
- SHT_
NULL - Section header table entry unused.
- SHT_NUM
- Number of defined types.
- SHT_
PREINIT_ ARRAY - Array of pre-constructors.
- SHT_
PROGBITS - Program data.
- SHT_REL
- Relocation entries, no addends.
- SHT_
RELA - Relocation entries with addends.
- SHT_
SHLIB - Reserved.
- SHT_
STRTAB - String table.
- SHT_
SUNW_ COMDAT - SHT_
SUNW_ MOVE - SHT_
SUNW_ SYMINFO - SHT_
SYMTAB - Symbol table.
- SHT_
SYMTAB_ SHNDX - Extended section indeces.
- SHT_
X86_ 64_ UNWIND - X86-64 unwind information.
- SIZEOF_
SHDR